==> react-0.18.0.tgz: package/src/components/Select/Combobox/index.tsx <==
import { useState } from 'react';
import { useCombobox, UseComboboxStateChange } from 'downshift';
import classNames from 'classnames';

import { SelectButton } from '../button';
import { SelectList } from '../list';
import { SelectOption } from '../option';

interface ComboboxProps {
  className?: string;
  placeholder?: string;
  defaultValue?: string;
  onChange?: (
    changes: UseComboboxStateChange<{ label: string; value: string }>
  ) => void;
  options?: { value: string; label: string }[];
}

export function Combobox({
  className,
  placeholder,
  defaultValue,
  onChange,
  options = [],
}: ComboboxProps) {
  const [inputItems, setInputItems] = useState<
    { label: string; value: string }[]
  >(options);

  const {
    isOpen,
    getToggleButtonProps,
    getMenuProps,
    getItemProps,
    getInputProps,
    getComboboxProps,
    highlightedIndex,
    selectItem,
  } = useCombobox({
    items: inputItems,
    itemToString: item => (!!item?.label ? item.label : ''),
    onSelectedItemChange: onChange,
    onInputValueChange: ({ inputValue }) => {
      setInputItems(
        options.filter(item =>
          item.label
            .toLowerCase()
            .includes(inputValue ? inputValue.toLowerCase() : '')
        )
      );
    },
  });

  const initialValue = options.find(option => option.value === defaultValue);
  if (defaultValue && initialValue) selectItem(initialValue);

  return (
    <div className={classNames('relative focus:outline-none', className)}>
      <div {...getComboboxProps()}>
        <SelectButton isOpen={isOpen} {...getToggleButtonProps()}>
          <input
            className="w-full h-full appearance-none focus:outline-none"
            placeholder={placeholder}
            {...getInputProps()}
          />
        </SelectButton>
      </div>
      <div
        className={classNames(
          'mt-2 focus:outline-none transition transform duration-300',
          {
            'opacity-0 translate-y-2': !isOpen,
            'opacity-100 translate-y-0': isOpen,
          }
        )}
        {...getMenuProps()}
      >
        {isOpen && (
          <SelectList>
            {inputItems.map((item, index) => (
              <SelectOption
                key={item.value}
                highlighted={highlightedIndex === index}
                {...getItemProps({ item, index })}
              >
                {item.label}
              </SelectOption>
            ))}
          </SelectList>
        )}
      </div>
    </div>
  );
}

==> react-0.19.0.tgz: package/src/components/Select/Combobox/index.tsx <==
import { useState } from 'react';
import { useCombobox, UseComboboxStateChange } from 'downshift';
import classNames from 'classnames';

import { SelectButton } from '../button';
import { SelectList } from '../list';
import { SelectOption } from '../option';

interface ComboboxProps {
  className?: string;
  placeholder?: string;
  defaultValue?: string;
  onChange?: (
    changes: UseComboboxStateChange<{ label: string; value: string }>
  ) => void;
  options?: { value: string; label: string }[];
}

export function Combobox({
  className,
  placeholder,
  defaultValue,
  onChange,
  options = [],
}: ComboboxProps) {
  const [inputItems, setInputItems] = useState<
    { label: string; value: string }[]
  >(options);

  const {
    isOpen,
    getToggleButtonProps,
    getMenuProps,
    getItemProps,
    getInputProps,
    getComboboxProps,
    highlightedIndex,
    selectItem,
    selectedItem,
    reset,
  } = useCombobox({
    items: inputItems,
    itemToString: item => (!!item?.label ? item.label : ''),
    onSelectedItemChange: onChange,
    onInputValueChange: ({ inputValue }) => {
      setInputItems(
        options.filter(item =>
          item.label
            .toLowerCase()
            .includes(inputValue ? inputValue.toLowerCase() : '')
        )
      );
      if (!inputValue) reset();
    },
  });

  const initialValue = options.find(option => option.value === defaultValue);
  if (defaultValue && initialValue) selectItem(initialValue);

  return (
    <div className={classNames('relative focus:outline-none', className)}>
      <div {...getComboboxProps()}>
        <SelectButton
          className={classNames({
            'text-grayDark': selectedItem,
            'text-gray': !selectedItem,
          })}
          isOpen={isOpen}
          {...getToggleButtonProps()}
        >
          <input
            className="w-full h-full appearance-none focus:outline-none"
            placeholder={placeholder}
            {...getInputProps()}
          />
        </SelectButton>
      </div>
      <div
        className={classNames(
          'focus:outline-none transition transform duration-300',
          {
            'opacity-0 translate-y-2': !isOpen,
            'opacity-100 translate-y-0': isOpen,
          }
        )}
        {...getMenuProps()}
      >
        {isOpen && (
          <SelectList className="mt-2">
            {inputItems.map((item, index) => (
              <SelectOption
                key={item.value}
                highlighted={highlightedIndex === index}
                {...getItemProps({ item, index })}
              >
                {item.label}
              </SelectOption>
            ))}
          </SelectList>
        )}
      </div>
    </div>
  );
}
